window.Gleam.initSearch([{"doc":"gleepl","title":"gleepl","content":"# gleepl - A Gleam client for the [DeepL API](https://developers.deepl.com/docs/api-reference/translate)\n\n[![Package Version](https://img.shields.io/hexpm/v/gleepl)](https://hex.pm/packages/gleepl)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleepl/)\n\n## Installation\n\n```sh\ngleam add gleepl\n```\n\n## Usage\n\n```gleam\nimport gleepl\nimport gleepl/endpoints\nimport gleepl/langs\n\ngleepl.new()\n|&gt; gleepl.set_auth_key(&quot;YOUR_AUTH_KEY or from dot_env&quot;)\n|&gt; gleepl.set_endpoint(endpoints.free)\n|&gt; gleepl.set_from(langs.english)\n|&gt; gleepl.set_to(langs.french)\n|&gt; gleepl.translate(&quot;hello, friend!&quot;)\n\n// -&gt; Ok(&quot;Bonjour, mon ami !&quot;)\n```\n\n## Usage with [dot_env](https://hexdocs.pm/dot_env)\n\n```gleam\nimport dot_env\nimport dot_env/env\nimport gleepl\nimport gleepl/endpoints\nimport gleepl/langs\n\ndot_env.load()\nlet assert Ok(auth_key) = env.get(&quot;DEEPL_AUTH_KEY&quot;)\n\ngleepl.new()\n|&gt; gleepl.set_auth_key(auth_key)\n|&gt; gleepl.set_endpoint(endpoints.free)\n|&gt; gleepl.set_from(langs.english)\n|&gt; gleepl.set_to(langs.french)\n|&gt; gleepl.translate(&quot;hello, friend!&quot;)\n\n// -&gt; Ok(&quot;Bonjour, mon ami !&quot;)\n```\n\n## Development\n\n```sh\n# do not forget to add your DEEPL_AUTH_KEY to .env\n\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"gleepl/endpoints","title":"Endpoint","content":"pub type Endpoint {\n  Endpoint(String)\n}\n The Endpoint type represents the deepl uri to use for the translation request. As deepl offers a free and paid endpoint.\n You will need to choose which one to use. Defaults to the free endpoint when not set.\nEndpoint(String)\n\n\nSynonyms:\ngleepl/endpoints.Endpoint\ngleepl/endpoints Endpoint","url":"gleepl/endpoints.html#Endpoint"},{"doc":"gleepl/endpoints","title":"free","content":"pub const free: Endpoint\n \n free\n // -&gt; Endpoint(&quot;https://api-free.deepl.com/v2/translate&quot;)\n \nSynonyms:\ngleepl/endpoints.free\ngleepl/endpoints free","url":"gleepl/endpoints.html#free"},{"doc":"gleepl/endpoints","title":"paid","content":"pub const paid: Endpoint\n \n paid\n // -&gt; Endpoint(&quot;https://api.deepl.com/v2/translate&quot;)\n \nSynonyms:\ngleepl/endpoints.paid\ngleepl/endpoints paid","url":"gleepl/endpoints.html#paid"},{"doc":"gleepl/endpoints","title":"gleepl/endpoints","content":"","url":"gleepl/endpoints.html"},{"doc":"gleepl/langs","title":"Language","content":"pub type Language {\n  Language(String)\n}\n The language type is used to set the source and target language iso codes for deepl.\nLanguage(String)\n\n\nSynonyms:\ngleepl/langs.Language\ngleepl/langs Language","url":"gleepl/langs.html#Language"},{"doc":"gleepl/langs","title":"english","content":"pub const english: Language\n\nSynonyms:\ngleepl/langs.english\ngleepl/langs english","url":"gleepl/langs.html#english"},{"doc":"gleepl/langs","title":"french","content":"pub const french: Language\n\nSynonyms:\ngleepl/langs.french\ngleepl/langs french","url":"gleepl/langs.html#french"},{"doc":"gleepl/langs","title":"german","content":"pub const german: Language\n\nSynonyms:\ngleepl/langs.german\ngleepl/langs german","url":"gleepl/langs.html#german"},{"doc":"gleepl/langs","title":"slovenian","content":"pub const slovenian: Language\n\nSynonyms:\ngleepl/langs.slovenian\ngleepl/langs slovenian","url":"gleepl/langs.html#slovenian"},{"doc":"gleepl/langs","title":"from_iso","content":"pub fn from_iso(iso: String) -&gt; Language\n Returns a language type for the iso language code without having to wait for gleepl updates.\n\n\n [supported languages](https://developers.deepl.com/docs/resources/supported-languages#target-languages)\n\n ### Example\n\n \n from_iso(&quot;es&quot;)\n // -&gt; Language(&quot;es&quot;)\n \nSynonyms:\ngleepl/langs.from_iso\ngleepl/langs from_iso","url":"gleepl/langs.html#from_iso"},{"doc":"gleepl/langs","title":"gleepl/langs","content":" The language constants are for convenience so that you do not have to remember the iso codes. They are not neccessary and you can use the `from_iso` function to set the language for any missing languages.\n A list of suported languages can be found here: [deepl supported languages](https://developers.deepl.com/docs/resources/supported-languages#target-languages)","url":"gleepl/langs.html"},{"doc":"gleepl","title":"TranslationRequest","content":"pub type TranslationRequest {\n  TranslationRequest(\n    auth_key: Option(String),\n    endpoint: Option(endpoints.Endpoint),\n    from: Option(Language),\n    to: Option(Language),\n    text: Option(String),\n  )\n}\n\nTranslationRequest(\n  auth_key: Option(String),\n  endpoint: Option(endpoints.Endpoint),\n  from: Option(Language),\n  to: Option(Language),\n  text: Option(String),\n)\n\n\nSynonyms:\ngleepl.TranslationRequest\ngleepl TranslationRequest","url":"gleepl.html#TranslationRequest"},{"doc":"gleepl","title":"new","content":"pub fn new() -&gt; TranslationRequest\n Initializes a new  translation request\nSynonyms:\ngleepl.new\ngleepl new","url":"gleepl.html#new"},{"doc":"gleepl","title":"set_auth_key","content":"pub fn set_auth_key(\n  request: TranslationRequest,\n  auth_key: String,\n) -&gt; TranslationRequest\n Sets the auth key for the request\n\n ### Example\n\n \n gleepl.new()\n |&gt; gleepl.set_auth_key(&quot;&lt;your-auth-key&gt;&quot;)\n \nSynonyms:\ngleepl.set_auth_key\ngleepl set_auth_key","url":"gleepl.html#set_auth_key"},{"doc":"gleepl","title":"set_endpoint","content":"pub fn set_endpoint(\n  request: TranslationRequest,\n  endpoint: Endpoint,\n) -&gt; TranslationRequest\n Sets the endpoint for the request as deepl offers both free and paid endpoints. Defaults to free if not set.\n\n ### Examples\n\n \n import gleepl/endpoints\n\n gleepl.new()\n |&gt; gleepl.set_endpoint(endpoints.free)\n \n\n \n import gleepl/endpoints\n\n gleepl.new()\n |&gt; gleepl.set_endpoint(endpoints.paid)\n \nSynonyms:\ngleepl.set_endpoint\ngleepl set_endpoint","url":"gleepl.html#set_endpoint"},{"doc":"gleepl","title":"set_from","content":"pub fn set_from(\n  request: TranslationRequest,\n  language: Language,\n) -&gt; TranslationRequest\n Sets the language to translate from (deepl source language)\n\n ### Examples\n\n \n import gleepl/langs\n\n gleepl.new()\n |&gt; gleepl.set_from(langs.english)\n \n\n \n import gleepl/langs\n \n gleepl.new()\n |&gt; gleepl.set_from(langs.from_iso(&quot;es&quot;))\n \nSynonyms:\ngleepl.set_from\ngleepl set_from","url":"gleepl.html#set_from"},{"doc":"gleepl","title":"set_text","content":"pub fn set_text(\n  request: TranslationRequest,\n  text: String,\n) -&gt; TranslationRequest\n Sets the text to translate\n\n ### Example\n\n \n gleepl.new()\n |&gt; gleepl.set_text(&quot;hello, friend!&quot;)\n \nSynonyms:\ngleepl.set_text\ngleepl set_text","url":"gleepl.html#set_text"},{"doc":"gleepl","title":"set_to","content":"pub fn set_to(\n  request: TranslationRequest,\n  language: Language,\n) -&gt; TranslationRequest\n Sets the language to translate to (deepl target language)\n\n ### Examples\n\n \n import gleepl/langs\n\n gleepl.new()\n |&gt; gleepl.set_to(langs.french)\n \n\n \n import gleepl/langs\n \n gleepl.new()\n |&gt; gleepl.set_to(langs.from_iso(&quot;es&quot;))\n \nSynonyms:\ngleepl.set_to\ngleepl set_to","url":"gleepl.html#set_to"},{"doc":"gleepl","title":"translate","content":"pub fn translate(\n  request: TranslationRequest,\n) -&gt; Result(String, Dynamic)\n Executes the request and returns the translated text\n\n ### Example\n\n \n import gleepl/endpoints\n import gleepl/langs\n\n gleepl.new()\n |&gt; gleepl.set_auth_key(&quot;&lt;your-auth-key&gt;&quot;)\n |&gt; gleepl.set_endpoint(endpoints.free)\n |&gt; gleepl.set_from(langs.english)\n |&gt; gleepl.set_to(langs.french)\n |&gt; gleepl.set_text(&quot;hello, friend!&quot;)\n |&gt; gleepl.translate\n\n // -&gt; Ok(&quot;Bonjour, mon ami !&quot;)\nSynonyms:\ngleepl.translate\ngleepl translate","url":"gleepl.html#translate"},{"doc":"gleepl","title":"gleepl","content":"","url":"gleepl.html"}]);